@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '1.00';
 
 sub WriteAutoXSHeader {
   my $filename = shift;
@@ -21,6 +21,17 @@ typedef struct {
   SV* key;
 } autoxs_hashkey;
 
+/* prototype section */
+
+I32 get_hashkey_index(const char* key, const I32 len);
+I32 _new_hashkey();
+void _resize_array(I32** array, unsigned int* len, unsigned int newlen);
+void _resize_array_init(I32** array, unsigned int* len, unsigned int newlen, I32 init);
+I32 _new_internal_arrayindex();
+I32 get_internal_array_index(I32 object_ary_idx);
+
+/* initialization section */
+
 unsigned int AutoXS_no_hashkeys = 0;
 unsigned int AutoXS_free_hashkey_no = 0;
 autoxs_hashkey* AutoXS_hashkeys = NULL;
@@ -33,6 +44,9 @@ I32* AutoXS_arrayindices = NULL;
 unsigned int AutoXS_reverse_arrayindices_length = 0;
 I32* AutoXS_reverse_arrayindices = NULL;
 
+
+/* implementation section */
+
 I32 get_hashkey_index(const char* key, const I32 len) {
   /* init */
   if (AutoXS_reverse_hashkeys == NULL)
@@ -125,7 +139,6 @@ I32 get_internal_array_index(I32 object_ary_idx) {
   AutoXS_reverse_arrayindices[object_ary_idx] = new_index;
   return new_index;
 }
-
 AUTOXSHEADERHEREDOC
 }
 
